@@ -18,10 +18,7 @@
     Boston, MA 02110-1301, USA.
 */
 
-#include <QFile>
-#include <QTextStream>
-#include <QTextCodec>
-#include <QRegExp>
+#include "kabc/stdaddressbook.h"
 
 #include <kaboutdata.h>
 #include <kapplication.h>
@@ -30,16 +27,19 @@
 #include <kglobal.h>
 #include <kstandarddirs.h>
 
-#include "kabc/stdaddressbook.h"
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
+#include <QtCore/QTextCodec>
+#include <QtCore/QRegExp>
 
 using namespace KABC;
 
-int main(int argc,char **argv)
+int main( int argc, char **argv )
 {
-  KAboutData aboutData("kabcargl","Fix broken pre3.0rc3 format","0.1");
-  aboutData.addAuthor("Cornelius Schumacher", 0, "schumacher@kde.org");
+  KAboutData aboutData( "kabcargl", 0, ki18n( "Fix broken pre3.0rc3 format" ), "0.1" );
+  aboutData.addAuthor( ki18n( "Cornelius Schumacher" ), KLocalizedString(), "schumacher@kde.org" );
 
-  KCmdLineArgs::init(argc,argv,&aboutData);
+  KCmdLineArgs::init( argc, argv, &aboutData );
 
   KApplication app;
 
@@ -47,12 +47,12 @@ int main(int argc,char **argv)
 
   QFile f( filename );
   if ( !f.open( QIODevice::ReadOnly ) ) {
-    kDebug() << "Error opening file '" << filename << "' for reading." << endl;
+    kDebug() << "Error opening file '" << filename << "' for reading.";
     return 1;
   }
 
   QTextStream t( &f );
-  t.setCodec(QTextCodec::codecForName("UTF-8"));
+  t.setCodec( QTextCodec::codecForName( "UTF-8" ) );
   QString text = t.readAll();
   f.close();
 
@@ -60,12 +60,12 @@ int main(int argc,char **argv)
   text.replace( "\n", "\r\n" );
 
   if ( !f.open( QIODevice::WriteOnly ) ) {
-    kDebug() << "Error opening file '" << filename << "' for writing." << endl;
+    kDebug() << "Error opening file '" << filename << "' for writing.";
     return 1;
   }
 
   QTextStream t2( &f );
-  t2.setCodec(QTextCodec::codecForName("UTF-8"));
+  t2.setCodec( QTextCodec::codecForName( "UTF-8" ) );
   t2 << text;
   f.close();
 }
