@@ -28,8 +28,8 @@
 #include <kcmdlineargs.h>
 #include <ksystemtimezone.h>
 
-#include <QFile>
-#include <QTextStream>
+#include <QtCore/QFile>
+#include <QtCore/QTextStream>
 
 
 
@@ -37,23 +37,20 @@ using namespace KCal;
 
 static QString dumpTime( const KDateTime &dt, const KDateTime::Spec &viewSpec );
 
-static const KCmdLineOptions options[] =
-{
-  { "verbose", "Verbose output", 0 },
-  { "+input", "Name of input file", 0 },
-  { "[+output]", "optional name of output file for the recurrence dates", 0 },
-  KCmdLineLastOption
-};
-
 
 int main( int argc, char **argv )
 {
-  KAboutData aboutData( "testrecurrencenew", "Load recurrence rules with the new class and print out debug messages", "0.1" );
+  KAboutData aboutData( "testrecurrencenew", 0, ki18n("Load recurrence rules with the new class and print out debug messages"), "0.1" );
   KCmdLineArgs::init( argc, argv, &aboutData );
+
+  KCmdLineOptions options;
+  options.add("verbose", ki18n("Verbose output"));
+  options.add("+input", ki18n("Name of input file"));
+  options.add("[+output]", ki18n("optional name of output file for the recurrence dates"));
   KCmdLineArgs::addCmdLineOptions( options );
 
   KComponentData componentData( &aboutData );
-  //QCoreApplication app( *KCmdLineArgs::qt_argc(), *KCmdLineArgs::qt_argv() );
+  //QCoreApplication app( KCmdLineArgs::qtArgc(), KCmdLineArgs::qtArgv() );
 
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
@@ -61,19 +58,19 @@ int main( int argc, char **argv )
     args->usage( "Wrong number of arguments." );
   }
 
-  QString input = QFile::decodeName( args->arg( 0 ) );
-  kDebug(5800) << "Input file: " << input << endl;
+  QString input = args->arg( 0 );
+  kDebug(5800) << "Input file:" << input;
 
   QTextStream *outstream;
   outstream = 0;
   QString fn("");
   if ( args->count() > 1 ) {
     fn = args->arg( 1 );
-    kDebug() << "We have a file name given: " << fn << endl;
+    kDebug() << "We have a file name given:" << fn;
   }
   QFile outfile( fn );
   if ( !fn.isEmpty() && outfile.open( QIODevice::WriteOnly ) ) {
-    kDebug() << "Opened output file!!!" << endl;
+    kDebug() << "Opened output file!!!";
     outstream = new QTextStream( &outfile );
   }
 
@@ -90,8 +87,8 @@ int main( int argc, char **argv )
 
   for ( Incidence::List::Iterator it = inc.begin(); it != inc.end(); ++it ) {
     Incidence *incidence = *it;
-    kDebug(5800) << "*+*+*+*+*+*+*+*+*+*" << endl;
-    kDebug(5800) << " -> " << incidence->summary() << " <- " << endl;
+    kDebug(5800) << "*+*+*+*+*+*+*+*+*+*";
+    kDebug(5800) << " ->" << incidence->summary() << "<-";
 
     incidence->recurrence()->dump();
 
@@ -106,8 +103,8 @@ int main( int argc, char **argv )
 	}
       }
       else dt = dt.addYears( 2 );
-      kDebug(5800) << "-------------------------------------------" << endl;
-      kDebug(5800) << " *~*~*~*~ Starting with date: " << dumpTime(dt, viewSpec) << endl;
+      kDebug(5800) << "-------------------------------------------";
+      kDebug(5800) << " *~*~*~*~ Starting with date:" << dumpTime(dt, viewSpec);
       // Output to file for testing purposes
       while (dt.isValid() && i<500 ) {
         ++i;
@@ -116,18 +113,18 @@ int main( int argc, char **argv )
           (*outstream) << dumpTime(dt, viewSpec) << endl;
       }
     } else {
-      if ( !dt.isValid() ) dt = KDateTime( QDate( 2005, 7, 31 ), QTime( 23, 59, 59 ), KDateTime::Spec::UTC );
+      if ( !dt.isValid() ) dt = KDateTime( QDate( 2005, 7, 31 ), QTime( 23, 59, 59 ), KDateTime::Spec::UTC() );
       else dt = dt.addYears( 2 );
       incidence->recurrence()->dump();
-      kDebug(5800) << "-------------------------------------------" << endl;
-      kDebug(5800) << " *~*~*~*~ Starting with date: " << dumpTime(dt, viewSpec) << endl;
+      kDebug(5800) << "-------------------------------------------";
+      kDebug(5800) << " *~*~*~*~ Starting with date:" << dumpTime(dt, viewSpec);
       // Output to konsole
       while ( dt.isValid() && i<50 ) {
         ++i;
-        kDebug(5800) << "-------------------------------------------" << endl;
+        kDebug(5800) << "-------------------------------------------";
         dt = incidence->recurrence()->getPreviousDateTime( dt );
         if ( dt.isValid() )
-          kDebug(5800) << " *~*~*~*~ Previous date is: " << dumpTime(dt, viewSpec) << endl;
+          kDebug(5800) << " *~*~*~*~ Previous date is:" << dumpTime(dt, viewSpec);
       }
     }
   }
