@@ -159,7 +159,7 @@ sigchld_handler (int signo)
 }
 
 IMAP4Protocol::IMAP4Protocol (const QByteArray & pool, const QByteArray & app, bool isSSL)
-  :TCPSlaveBase ((isSSL ? 993 : 143), (isSSL ? IMAP_SSL_PROTOCOL : IMAP_PROTOCOL), pool, app, isSSL),
+  :TCPSlaveBase ((isSSL ? IMAP_SSL_PROTOCOL : IMAP_PROTOCOL), pool, app, isSSL),
    imapParser (),
    mimeIO (),
    mySSL( isSSL ),
@@ -177,7 +177,7 @@ IMAP4Protocol::IMAP4Protocol (const QByteArray & pool, const QByteArray & app, b
 
 IMAP4Protocol::~IMAP4Protocol ()
 {
-  closeDescriptor();
+  disconnectFromHost();
   kDebug(7116) <<"IMAP4: Finishing";
 }
 
@@ -313,7 +313,7 @@ IMAP4Protocol::get (const KUrl & _url)
         cmd = sendCommand (imapCommand::clientFetch (aSequence, mySection));
         do
         {
-          while (!parseLoop ());
+          while (!parseLoop ()) {}
         }
         while (!cmd->isComplete ());
         completeQueue.removeAll (cmd);
@@ -332,7 +332,7 @@ IMAP4Protocol::get (const KUrl & _url)
       aUpper = aSection.toUpper();
       do
       {
-        while (!(res = parseLoop()));
+        while (!(res = parseLoop())) {}
         if (res == -1) break;
 
         mailHeader *lastone = 0;
@@ -594,7 +594,7 @@ IMAP4Protocol::listDir (const KUrl & _url)
         imapCache *cache;
         do
         {
-          while (!parseLoop ());
+          while (!parseLoop ()) {}
 
           cache = getLastHandled ();
 
@@ -738,7 +738,7 @@ bool IMAP4Protocol::parseReadLine (QByteArray & buffer, long relay)
         memmove(readBuffer, &readBuffer[copyLen], readBufferLen);
       if (buffer[buffer.size() - 1] == '\n') return true;
     }
-    if (!isConnectionValid())
+    if (!isConnected())
     {
       kDebug(7116) <<"parseReadLine - connection broken";
       error (ERR_CONNECTION_BROKEN, myHost);
@@ -825,7 +825,7 @@ IMAP4Protocol::put (const KUrl & _url, int, KIO::JobFlags)
 
     imapCommand *cmd =
       sendCommand (imapCommand::clientAppend (aBox, aSection, length));
-    while (!parseLoop ());
+    while (!parseLoop ()) {}
 
     // see if server is waiting
     if (!cmd->isComplete () && !getContinuation ().isEmpty ())
@@ -1208,6 +1208,7 @@ IMAP4Protocol::del (const KUrl & _url, bool isFile)
  * AnnotateMore commands: data = 'M' + 'G'et/'S'et + URL + entry + command-dependent args
  * Search: data = 'E' + URL (KUrl)
  * Quota commands: data = 'Q' + 'R'oot/'G'et/'S'et + URL + entry + command-dependent args
+ * Custom command: data = 'X' + 'N'ormal/'E'xtended + command + command-dependent args
  */
 void
 IMAP4Protocol::special (const QByteArray & aData)
@@ -1249,6 +1250,7 @@ IMAP4Protocol::special (const QByteArray & aData)
       return;
     }
     completeQueue.removeAll (cmd);
+    delete cmd;
     finished();
     break;
   }
@@ -1419,6 +1421,12 @@ IMAP4Protocol::special (const QByteArray & aData)
     specialSearchCommand( stream );
     break;
   }
+  case 'X':
+  {
+    // custom command
+    specialCustomCommand( stream );
+    break;
+  }
   default:
     kWarning(7116) <<"Unknown command in special():" << tmp;
     error( ERR_UNSUPPORTED_ACTION, QString(QChar(tmp)) );
@@ -1556,6 +1564,85 @@ IMAP4Protocol::specialSearchCommand( QDataStream& stream )
   finished();
 }
 
+void
+IMAP4Protocol::specialCustomCommand( QDataStream& stream )
+{
+  kDebug(7116) << "IMAP4Protocol::specialCustomCommand" << endl;
+
+  QString command, arguments;
+  int type;
+  stream >> type;
+  stream >> command >> arguments;
+
+  /**
+   * In 'normal' mode we send the command with all information in one go
+   * and retrieve the result.
+   */
+  if ( type == 'N' ) {
+    kDebug(7116) << "IMAP4Protocol::specialCustomCommand: normal mode" << endl;
+    imapCommand *cmd = doCommand (imapCommand::clientCustom( command, arguments ));
+    if (cmd->result () != "OK")
+    {
+      error(ERR_SLAVE_DEFINED, i18n("Custom command %1:%2 "
+            "failed. The server returned: %3")
+          .arg(command)
+          .arg(arguments)
+          .arg(cmd->resultInfo()));
+      return;
+    }
+    completeQueue.removeAll(cmd);
+    QStringList lst = getResults();
+    kDebug(7116) << "IMAP4Protocol::specialCustomCommand '" << command <<
+      ":" << arguments <<
+      "' returns " << lst << endl;
+    infoMessage( lst.join( " " ) );
+
+    finished();
+  } else
+  /**
+   * In 'extended' mode we send a first header and push the data of the request in
+   * streaming mode.
+   */
+  if ( type == 'E' ) {
+    kDebug(7116) << "IMAP4Protocol::specialCustomCommand: extended mode" << endl;
+    imapCommand *cmd = sendCommand (imapCommand::clientCustom( command, QString() ));
+    while ( !parseLoop () );
+
+    // see if server is waiting
+    if (!cmd->isComplete () && !getContinuation ().isEmpty ())
+    {
+      const QByteArray buffer = arguments.toUtf8();
+
+      // send data to server
+      bool sendOk = (write (buffer.data (), buffer.size ()) == (ssize_t)buffer.size ());
+      processedSize( buffer.size() );
+
+      if ( !sendOk ) {
+        error ( ERR_CONNECTION_BROKEN, myHost );
+        completeQueue.removeAll ( cmd );
+        setState(ISTATE_CONNECT);
+        closeConnection();
+        return;
+      }
+    }
+    parseWriteLine ("");
+
+    do
+    {
+      while (!parseLoop ());
+    }
+    while (!cmd->isComplete ());
+
+    completeQueue.removeAll (cmd);
+
+    QStringList lst = getResults();
+    kDebug(7116) << "IMAP4Protocol::specialCustomCommand: returns " << lst << endl;
+    infoMessage( lst.join( " " ) );
+
+    finished ();
+  }
+}
+
 void
 IMAP4Protocol::specialAnnotateMoreCommand( int command, QDataStream& stream )
 {
@@ -1729,7 +1816,7 @@ IMAP4Protocol::rename (const KUrl & src, const KUrl & dest, KIO::JobFlags flags)
 void
 IMAP4Protocol::slave_status ()
 {
-  bool connected = (getState() != ISTATE_NO) && isConnectionValid();
+  bool connected = (getState() != ISTATE_NO) && isConnected();
   kDebug(7116) <<"IMAP4::slave_status" << connected;
   slaveStatus ( connected ? myHost : QString(), connected );
 }
@@ -1904,7 +1991,7 @@ void IMAP4Protocol::closeConnection()
     imapCommand *cmd = doCommand (imapCommand::clientLogout());
     completeQueue.removeAll (cmd);
   }
-  closeDescriptor();
+  disconnectFromHost();
   setState(ISTATE_NO);
   completeQueue.clear();
   sentQueue.clear();
@@ -1935,7 +2022,7 @@ bool IMAP4Protocol::makeLogin ()
     imapCommand *cmd;
 
     unhandled.clear ();
-    if (!alreadyConnected) while (!parseLoop ());    //get greeting
+    if (!alreadyConnected) while (!parseLoop ()) {}   //get greeting
     QString greeting;
     if (!unhandled.isEmpty()) greeting = unhandled.first().trimmed();
     unhandled.clear ();       //get rid of it
@@ -1948,6 +2035,7 @@ bool IMAP4Protocol::makeLogin ()
       kDebug(7116) <<"'" << (*it) <<"'";
     }
     completeQueue.removeAll (cmd);
+    delete cmd;
 
     if (!hasCapability("IMAP4") && !hasCapability("IMAP4rev1"))
     {
@@ -1967,15 +2055,14 @@ bool IMAP4Protocol::makeLogin ()
       closeConnection();
       return false;
     }
-    if ((myTLS == "on" || (canUseTLS() && myTLS != "off")) &&
-      hasCapability(QString("STARTTLS")))
+    if ((myTLS == "on" /*###|| ( canUseTLS() && myTLS != "off")*/) &&
+        hasCapability(QString("STARTTLS")))
     {
       imapCommand *cmd = doCommand (imapCommand::clientStartTLS());
       if (cmd->result () == "OK")
       {
         completeQueue.removeAll(cmd);
-        int tlsrc = startTLS();
-        if (tlsrc == 1)
+        if (startSsl())
         {
           kDebug(7116) <<"TLS mode has been enabled.";
           imapCommand *cmd2 = doCommand (new imapCommand ("CAPABILITY", ""));
@@ -1989,9 +2076,11 @@ bool IMAP4Protocol::makeLogin ()
           kWarning(7116) <<"TLS mode setup has failed.  Aborting.";
           error (ERR_COULD_NOT_LOGIN, i18n("Starting TLS failed."));
           closeConnection();
+          delete cmd;
           return false;
         }
       } else completeQueue.removeAll(cmd);
+      delete cmd;
     }
 
     if (!myAuth.isEmpty () && myAuth != "*"
@@ -2051,6 +2140,7 @@ bool IMAP4Protocol::makeLogin ()
         kDebug(7116) <<"makeLogin - registered namespaces";
       }
       completeQueue.removeAll (cmd);
+      delete cmd;
     }
     // get the default delimiter (empty listing)
     cmd = doCommand( imapCommand::clientList("", "") );
@@ -2070,6 +2160,7 @@ bool IMAP4Protocol::makeLogin ()
       }
     }
     completeQueue.removeAll (cmd);
+    delete cmd;
   } else {
     kDebug(7116) <<"makeLogin - NO login";
   }
@@ -2151,10 +2242,10 @@ IMAP4Protocol::doListEntry (const QString & encodedUrl, int stretch, imapCache *
     entry.clear ();
 
     const QString uid = QString::number(cache->getUid());
-	QString tmp;
+    QString tmp = uid;
     if (stretch > 0)
     {
-      tmp = "0000000000000000" + tmp;
+      tmp = "0000000000000000" + uid;
       tmp = tmp.right (stretch);
     }
     if (withSubject)
@@ -2486,7 +2577,7 @@ ssize_t IMAP4Protocol::myRead(void *data, ssize_t len)
     if (readBufferLen) memcpy(readBuffer, &readBuffer[copyLen], readBufferLen);
     return copyLen;
   }
-  if (!isConnectionValid()) return 0;
+  if (!isConnected()) return 0;
   waitForResponse( responseTimeout() );
   return read((char*)data, len);
 }
