@@ -41,6 +41,7 @@ void HeaderTest::testIdentHeader()
   h->from7BitString( QByteArray( "<1162746587.784559.5038.nullmailer@svn.kde.org>" ) );
   QCOMPARE( h->identifiers().count(), 1 );
   QCOMPARE( h->identifiers().first(), QByteArray( "1162746587.784559.5038.nullmailer@svn.kde.org" ) );
+  QCOMPARE( h->asUnicodeString(), QString("<1162746587.784559.5038.nullmailer@svn.kde.org>") );
   QVERIFY( !h->isEmpty() );
 
   // clearing a header
@@ -229,6 +230,45 @@ void HeaderTest::testAddressListHeader()
   delete h;
 }
 
+void HeaderTest::testMailboxListHeader()
+{
+  // empty header
+  Headers::Generics::MailboxList *h = new Headers::Generics::MailboxList();
+  QVERIFY( h->isEmpty() );
+
+  // parse single simple address
+  h->from7BitString( "joe_smith@where.test" );
+  QVERIFY( !h->isEmpty() );
+  QCOMPARE( h->mailboxes().count(), 1 );
+  QCOMPARE( h->addresses().count(), 1 );
+  QCOMPARE( h->addresses().first(), QByteArray("joe_smith@where.test") );
+  QCOMPARE( h->displayNames().count(), 1 );
+  QCOMPARE( h->displayNames().first(), QString() );
+  QCOMPARE( h->prettyAddresses().count(), 1 );
+  QCOMPARE( h->prettyAddresses().first(), QString("joe_smith@where.test") );
+
+  delete h;
+}
+
+void HeaderTest::testSingleMailboxHeader()
+{
+  // empty header
+  Headers::Generics::SingleMailbox *h = new Headers::Generics::SingleMailbox();
+  QVERIFY( h->isEmpty() );
+
+  // parse single simple address
+  h->from7BitString( "joe_smith@where.test" );
+  QVERIFY( !h->isEmpty() );
+  QCOMPARE( h->addresses().count(), 1 );
+  QCOMPARE( h->addresses().first(), QByteArray("joe_smith@where.test") );
+  QCOMPARE( h->displayNames().count(), 1 );
+  QCOMPARE( h->displayNames().first(), QString() );
+  QCOMPARE( h->prettyAddresses().count(), 1 );
+  QCOMPARE( h->prettyAddresses().first(), QString("joe_smith@where.test") );
+
+  delete h;
+}
+
 void HeaderTest::testMailCopiesToHeader()
 {
   Headers::MailCopiesTo *h;
@@ -633,9 +673,23 @@ void HeaderTest::testControlHeader()
   delete h;
 }
 
+void HeaderTest::testReturnPath()
+{
+  ReturnPath *h;
+
+  h = new ReturnPath();
+  QVERIFY( h->isEmpty() );
+  QVERIFY( h->as7BitString().isEmpty() );
+
+  h->from7BitString( "<foo@bar>" );
+  QVERIFY( !h->isEmpty() );
+  QCOMPARE( h->as7BitString( true ), QByteArray( "Return-Path: <foo@bar>" ) );
+
+  delete h;
+}
+
 void HeaderTest::noAbstractHeaders()
 {
-  ReturnPath* h1 = new ReturnPath(); delete h1;
   From* h2 = new From(); delete h2;
   Sender* h3 = new Sender(); delete h3;
   To* h4 = new To(); delete h4;
