@@ -38,7 +38,7 @@ class QDataStream;
 class QDateTime;
 class QStringList;
 
-#include "ktnef.h"
+#include "ktnef_export.h"
 
 namespace KTnef {
 
@@ -289,6 +289,8 @@ private:
   class PrivateData;
   PrivateData *const d;
   //@endcond
+
+  Q_DISABLE_COPY( KTNEFWriter )
 };
 
 }
