@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -23,9 +23,8 @@
 #include "contentvocab.h"
 #include "property.h"
 
-#include <kstaticdeleter.h>
-
-#include <QString>
+#include <QtCore/QCoreApplication>
+#include <QtCore/QString>
 
 namespace Syndication {
 namespace RDF {
@@ -36,7 +35,15 @@ class ContentVocab::ContentVocabPrivate
         
     QString namespaceURI;
     PropertyPtr encoded;
+
+    static ContentVocab *sSelf;
+    static void cleanupContentVocab()
+    {
+        delete sSelf;
+        sSelf = 0;
+    }
 };
+ContentVocab *ContentVocab::ContentVocabPrivate::sSelf = 0;
 
 ContentVocab::ContentVocab() : d(new ContentVocabPrivate)
 {
@@ -44,27 +51,23 @@ ContentVocab::ContentVocab() : d(new ContentVocabPrivate)
     
     d->namespaceURI = ns;
     
-    d->encoded = new Property(ns + QString::fromUtf8("encoded"));
+    d->encoded = PropertyPtr( new Property(ns + QString::fromUtf8("encoded")) );
     
 }
 
 ContentVocab::~ContentVocab()
 {
     delete d;
-    d = 0;
 }
 
-//@cond PRIVATE
-static KStaticDeleter<ContentVocab> contentvocabsd;
-//@endcond
-
-ContentVocab* ContentVocab::m_self = 0;
-
 ContentVocab* ContentVocab::self()
 {
-    if (m_self == 0)
-        contentvocabsd.setObject(m_self, new ContentVocab);
-    return m_self;
+    static ContentVocabPrivate p;
+    if(!p.sSelf) {
+        p.sSelf = new ContentVocab;
+        qAddPostRoutine(ContentVocabPrivate::cleanupContentVocab);
+    }
+    return p.sSelf;
 }
         
 const QString& ContentVocab::namespaceURI() const
