@@ -1,7 +1,7 @@
 /*
  * This file is part of the syndication library
  *
- * Copyright (C) 2006 Frank Osterfeld <frank.osterfeld@kdemail.net>
+ * Copyright (C) 2006 Frank Osterfeld <osterfeld@kde.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -27,9 +27,8 @@
 #include <syndication/rdf/property.h>
 #include <syndication/rdf/sequence.h>
 #include <syndication/rdf/statement.h>
-#include <syndication/sharedptr.h>
-
-#include "ksyndication.h"
+#include <boost/shared_ptr.hpp>
+#include <syndication/ksyndication_export.h>
 
 #include <QtCore/QString>
 
@@ -248,7 +247,7 @@ class SYNDICATION_EXPORT Model
 
     private:
         class ModelPrivate;
-        SharedPtr<ModelPrivate> d;
+        boost::shared_ptr<ModelPrivate> d;
 };
 
 
